@@ -23,10 +23,9 @@
 #ifndef DLG_PASSWORD_H
 #define DLG_PASSWORD_H
 
-#include "window.h"
-
-
-void dlg_ask_password (FRWindow  *window);
+#include "fr-window.h"
 
+void dlg_ask_password (FrWindow  *window);
+void dlg_ask_password_for_paste_operation (FrWindow  *window);
 
 #endif /* DLG_PASSWORD_H */
