@@ -70,9 +70,9 @@ char *      _gtk_entry_get_filename_text    (GtkEntry   *entry);
 void        _gtk_label_set_filename_text    (GtkLabel   *label,
 					     const char *text);
 char *      _gtk_label_get_filename_text    (GtkLabel   *label);
-GdkPixbuf * get_icon_pixbuf                 (GtkIconTheme *icon_theme,
-		 			     GThemedIcon  *icon,
-		 			     int           size);
+GdkPixbuf * get_icon_pixbuf                 (GIcon        *icon,
+		 			     int           size,
+		 			     GtkIconTheme *icon_theme);
 GdkPixbuf * get_mime_type_pixbuf            (const char   *mime_type,
 		                             int           icon_size,
 		                             GtkIconTheme *icon_theme);
